kshell-utilities
================
Handy utilities for processing nuclear shell model data from KSHELL.

Installation
------------
Clone this repository to your downloads directory. cd to the root directory of this repository. Run ::
    
    pip install .
    
Or install from the PyPi repository (probably not the newest version) ::

    pip install kshell-utilities

Credit
------
KSHELL is created by Noritaka Shimizu ([arXiv:1310.5431 [nucl-th]](https://arxiv.org/abs/1310.5431)), and is available at https://sites.google.com/a/cns.s.u-tokyo.ac.jp/kshell/. Code in this repository is built upon tools created by Jørgen Eriksson Midtbø: https://github.com/jorgenem/kshell_public.
